diff --git a/docs/source/calibrator.rst b/docs/source/calibrator.rst
index 05be6471ac60fbfec1a6db3dbdb1b294b9f76a1d..a97b18d77a39399d33c64488a2254c983ef25737 100644
--- a/docs/source/calibrator.rst
+++ b/docs/source/calibrator.rst
@@ -39,7 +39,7 @@ The workflow ``prep`` consists of:
     - determining suitable calibrator skymodel (steps ``find_skymodel_cal``, ``make_sourcedb``)
     - checking for nearby A-Team sources (step ``check_Ateam_separation``)
     - creating a model of A-Team sources to be subtracted (step ``make_sourcedb_ateam``)
-    - basic flagging and averaging (subworkflow ``ndppp_prep_cal``)
+    - basic flagging and averaging (subworkflow ``dp3_prep_cal``)
         - edges of the band (``flagedge``) -- only used if ``raw_data : true``
         - statistical flagging (``aoflag``) -- only used in ``raw_data : true``
         - baseline flagging (``flagbaseline``)
@@ -276,7 +276,7 @@ A comprehensive explanation of the baseline selection syntax can be found `here`
 
 **Parameters for pipeline performance**
 
-- ``max_dppp_threads``: number of threads per process for DP3 (default: 10)
+- ``max_dp3_threads``: number of threads per process for DP3 (default: 10)
 - ``memoryperc``: maximum of memory used for aoflagger in raw_flagging mode in percent (default: 20)
 - ``aoflag_reorder``: make aoflagger reorder the measurement set before running the detection. This prevents that aoflagger will use its memory reading mode, which is faster but uses more memory (see the `AOFlagger manual`_`)
 
@@ -294,6 +294,6 @@ A comprehensive explanation of the baseline selection syntax can be found `here`
 - ``avg_freqresolution`` : final frequency resolution of the data after averaging (default: 48.82kHz, which translates to 4 channels per subband)
 - ``bandpass_freqresolution``: frequency resolution of the bandpass solution table (default: 195.3125kHz, which translates to 1 channel per subband)
 
-.. _here: https://www.astron.nl/lofarwiki/doku.php?id=public:user_software:documentation:ndppp#description_of_baseline_selection_parameters
+.. _here: https://dp3.readthedocs.io/en/latest/steps/Description%20of%20baseline%20selection%20parameters.html
 .. _AOFlagger: https://gitlab.com/aroffringa/aoflagger.git
 .. _AOFlagger manual: https://aoflagger.readthedocs.io/en/latest/using_aoflagger.html
\ No newline at end of file
diff --git a/docs/source/changelog.rst b/docs/source/changelog.rst
index 6d6da40bede33e258daa5851e328be5b810e6340..ce3d5a9b7b88fd83d396f7b8731f85a63cd164bd 100644
--- a/docs/source/changelog.rst
+++ b/docs/source/changelog.rst
@@ -36,7 +36,7 @@ Version 2.0
 
     * applying Ionospheric RM corrections
     * grouping of subbands by actual frequency
-    * speed and disk usage improvements by optimized usage of NDPPP
+    * speed and disk usage improvements by optimized usage of DP3
     * (optional) wide-band cleaning in Initial-Subtract
     * more diagnostic plots
     * documentation moved to GitHib wiki: https://github.com/lofar-astron/prefactor/wiki
diff --git a/docs/source/parset.rst b/docs/source/parset.rst
index 25684225cde07bb8d8a7dc2236ff76afeaecf293..75712bf64f487e76cb7d1bebe1345bb4409d4d63 100644
--- a/docs/source/parset.rst
+++ b/docs/source/parset.rst
@@ -19,16 +19,16 @@ A minimum input file may look like this::
 
     {
         "msin": [
-                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.dppp.MS"}
+                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.MS"}
                 ],
     }
 
@@ -36,16 +36,16 @@ There are more parameters you may want to adjust that can be added to this input
 
     {
         "msin": [
-                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.dppp.MS"}
+                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.MS"}
                 ],
         "refant": "CS00.*",
         "flag_baselines": [],
@@ -72,7 +72,7 @@ There are more parameters you may want to adjust that can be added to this input
         "ion_3rd": false,
         "clock_smooth": true,
         "tables2export": "clock",
-        "max_dppp_threads": 10,
+        "max_dp3_threads": 10,
         "memoryperc": 20,
         "min_separation": 30,
         "max_separation_arcmin": 1.0,
@@ -90,16 +90,16 @@ If you just want to alter one of the defaults it is sufficient to override it by
 
     {
         "msin": [
-                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.dppp.MS"},
-                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.dppp.MS"}
+                    {"class": "Directory", "path": "3C286/L228161_SB000_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB001_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB002_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB003_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB004_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB005_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB006_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB007_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB008_uv.MS"},
+                    {"class": "Directory", "path": "3C286/L228161_SB009_uv.MS"}
                 ],
         "demix": true,
     }
@@ -108,16 +108,16 @@ If you run the target pipeline you also need to provide the calibrator solution
 
     {
         "msin": [
-                    {"class": "Directory", "path": "?????/L228163_SB000_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB001_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB002_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB003_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB004_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB005_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB006_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB007_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB008_uv.dppp.MS"},
-                    {"class": "Directory", "path": "?????/L228163_SB009_uv.dppp.MS"}
+                    {"class": "Directory", "path": "?????/L228163_SB000_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB001_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB002_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB003_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB004_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB005_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB006_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB007_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB008_uv.MS"},
+                    {"class": "Directory", "path": "?????/L228163_SB009_uv.MS"}
                 ],
         "cal_solutions": {"class": "File", "path": "cal_solutions.h5"}
     }
diff --git a/docs/source/target.rst b/docs/source/target.rst
index 12435a8ccea3bf8de80f7862734c756fe67607f8..d51637e63c2adef2bfd4e515d24f094e81262f11 100644
--- a/docs/source/target.rst
+++ b/docs/source/target.rst
@@ -42,7 +42,7 @@ The workflow ``prep`` consists of:
 
     .. image:: RMextract.png
         
-    - basic flagging, applying solutions, and averaging (subworkflow ``ndppp_prep_target``)
+    - basic flagging, applying solutions, and averaging (subworkflow ``dp3_prep_target``)
         - edges of the band (``flagedge``) -- only used if ``raw_data : true``
         - statistical flagging (``aoflag``) -- only used in ``raw_data : true``
         - baseline flagging (``flagbaseline``)
@@ -302,9 +302,9 @@ A comprehensive explanation of the baseline selection syntax can be found `here`
 
 **Parameters for pipeline performance**
 
-- ``max_dppp_threads``: number of threads per process for DP3 (default: 10)
+- ``max_dp3_threads``: number of threads per process for DP3 (default: 10)
 - ``memoryperc``: maximum of memory used for aoflagger in raw_flagging mode in percent (default: 20)
-- ``aoflag_reorder``: make aoflagger reorder the measurement set before running the detection. This prevents that aoflagger will use its memory reading mode, which is faster but uses more memory (see the `AOFlagger manual`_`)
+- ``aoflag_reorder``: make aoflagger reorder the measurement set before running the detection. This prevents that aoflagger will use its memory reading mode, which is faster but uses more memory (see the `AOFlagger manual`_)
 
 *Skymodel directory*
 
@@ -342,8 +342,8 @@ If your **LBA** data has **not** been demixed before you may still want to keep
 .. _RMextract: https://github.com/lofar-astron/RMextract/
 .. _factor: https://github.com/lofar-astron/factor/
 .. _killMS: https://github.com/saopicc/killMS/
-.. _TGSS ADR: https://http://tgssadr.strw.leidenuniv.nl/
+.. _TGSS ADR: https://tgssadr.strw.leidenuniv.nl/
 .. _Dysco: https://github.com/aroffringa/dysco/
 .. _AOFlagger: https://gitlab.com/aroffringa/aoflagger.git
-.. _here: https://www.astron.nl/lofarwiki/doku.php?id=public:user_software:documentation:ndppp#description_of_baseline_selection_parameters
-.. _AOFlagger manual: https://aoflagger.readthedocs.io/en/latest/using_aoflagger.html
\ No newline at end of file
+.. _here: https://dp3.readthedocs.io/en/latest/steps/Description%20of%20baseline%20selection%20parameters.html
+.. _AOFlagger manual: https://aoflagger.readthedocs.io/en/latest/using_aoflagger.html
diff --git a/skymodels/3C295-sweijen.skymodel b/skymodels/3C295-sweijen.skymodel
index 08177ff6e80d912c21a3c9c51adeb902ef53171e..77ea67fe0e5a792d70d0543e6ad1e7fd3b97b484 100644
--- a/skymodels/3C295-sweijen.skymodel
+++ b/skymodels/3C295-sweijen.skymodel
@@ -2,7 +2,7 @@
 
 # This model of 3C 295 was created by Frits Sweijen.
 # A pointed 8 hour synthesis observation was taken early 2019 (surveys setup in terms of subbands) and all available international (DE, FR, IE, UK, PL, SE) stations were present.
-# Selfcal was done using the full bandwidth from about 121 MHz up to 168 MHz, using DPPP and WSClean.
+# Selfcal was done using the full bandwidth from about 121 MHz up to 168 MHz, using DP3 and WSClean.
 # WSClean's -spectral-correction option was used to try and keep the model at least somewhat near the Scaife&Heald scale, but no guarantees are given.
 # The bandpasses are not perfect yet, but are a lot better compared to the current two-component model.
 # If you want to share this model, please ask me first as it is planned to be used in a publication at some point.
diff --git a/steps/LoSoTo.Flag.cwl b/steps/LoSoTo.Flag.cwl
index 0437853669e605a4af64289e3631e3915153c682..988d55a4515263ae7eadbbee06cc1022a63bbc2e 100644
--- a/steps/LoSoTo.Flag.cwl
+++ b/steps/LoSoTo.Flag.cwl
@@ -82,7 +82,7 @@ inputs:
   - id: preflagzeros
     type: boolean?
     doc:
-      Flag zeros/ones (bad solutions in BBS/DPPP).
+      Flag zeros/ones (bad solutions in BBS/DP3).
       They should be flagged at import time. By default False.
   - id: mode
     type: string?
diff --git a/steps/dppp_make_parset_cal.cwl b/steps/dp3_make_parset_cal.cwl
similarity index 98%
rename from steps/dppp_make_parset_cal.cwl
rename to steps/dp3_make_parset_cal.cwl
index a5d394199280e016c82c07b7ad2e172a60c84767..4b5ad37c828d9ae53f98381e9cc99f5f60dab82e 100755
--- a/steps/dppp_make_parset_cal.cwl
+++ b/steps/dp3_make_parset_cal.cwl
@@ -60,7 +60,7 @@ outputs:
   - id: output
     type: File
     outputBinding:
-      glob: DPPP.parset
+      glob: DP3.parset
 baseCommand:
   - cp
 arguments:
@@ -71,7 +71,7 @@ arguments:
   - prefix: ''
     shellQuote: false
     position: 0
-    valueFrom: DPPP.parset
+    valueFrom: DP3.parset
 requirements:
   - class: InlineJavascriptRequirement
   - class: ShellCommandRequirement
diff --git a/steps/dppp_make_parset_target.cwl b/steps/dp3_make_parset_target.cwl
similarity index 99%
rename from steps/dppp_make_parset_target.cwl
rename to steps/dp3_make_parset_target.cwl
index 040c695a818c7a99b2ac34452fa50f5c6d03b736..6d9d93fbff7c1fe738d7f798715e41bb35077e7d 100755
--- a/steps/dppp_make_parset_target.cwl
+++ b/steps/dp3_make_parset_target.cwl
@@ -78,7 +78,7 @@ outputs:
   - id: output
     type: File
     outputBinding:
-      glob: DPPP.parset
+      glob: DP3.parset
 baseCommand:
   - cp
 arguments:
@@ -89,7 +89,7 @@ arguments:
   - prefix: ''
     shellQuote: false
     position: 0
-    valueFrom: DPPP.parset
+    valueFrom: DP3.parset
 requirements:
   - class: InlineJavascriptRequirement
   - class: ShellCommandRequirement
diff --git a/steps/dppp_prep_cal.cwl b/steps/dp3_prep_cal.cwl
similarity index 97%
rename from steps/dppp_prep_cal.cwl
rename to steps/dp3_prep_cal.cwl
index d574db8d6fdafa02ec5673904acc862af15b1563..dd39c7bb5513fc31ccdeb2cf74f0a9da74281681 100755
--- a/steps/dppp_prep_cal.cwl
+++ b/steps/dp3_prep_cal.cwl
@@ -1,6 +1,6 @@
 class: CommandLineTool
 cwlVersion: v1.2
-id: dppp
+id: dp3
 baseCommand:
   - DP3
 inputs:
@@ -107,12 +107,12 @@ outputs:
   - id: logfile
     type: File[]
     outputBinding:
-      glob: 'DPPP*.log'
+      glob: 'DP3*.log'
 hints:
   - class: DockerRequirement
     dockerPull: astronrd/linc
-stdout: DPPP.log
-stderr: DPPP_err.log
+stdout: DP3.log
+stderr: DP3_err.log
 requirements:
   - class: InlineJavascriptRequirement
   - class: ResourceRequirement
diff --git a/steps/dppp_prep_target.cwl b/steps/dp3_prep_target.cwl
similarity index 98%
rename from steps/dppp_prep_target.cwl
rename to steps/dp3_prep_target.cwl
index 27db45a7dafae6db7184b7c31c5f8698eb2ca75c..567b1106e6b21ec785d29e958c113a90b2dc76c7 100755
--- a/steps/dppp_prep_target.cwl
+++ b/steps/dp3_prep_target.cwl
@@ -1,6 +1,6 @@
 class: CommandLineTool
 cwlVersion: v1.2
-id: dppp
+id: dp3
 baseCommand:
   - DP3
 inputs:
@@ -163,12 +163,12 @@ outputs:
   - id: logfile
     type: File[]
     outputBinding:
-      glob: 'DPPP*.log'
+      glob: 'DP3*.log'
 hints:
   - class: DockerRequirement
     dockerPull: astronrd/linc
-stdout: DPPP.log
-stderr: DPPP_err.log
+stdout: DP3.log
+stderr: DP3_err.log
 requirements:
   - class: InlineJavascriptRequirement
   - class: ResourceRequirement
diff --git a/steps/dpppconcat.cwl b/steps/dp3concat.cwl
similarity index 99%
rename from steps/dpppconcat.cwl
rename to steps/dp3concat.cwl
index 08e3d3f7ba9ac89e2d0b9cdceaba7cdc783dff2b..d66d27f0de49e1c0d0b2251b3b4641ca51fe96fe 100644
--- a/steps/dpppconcat.cwl
+++ b/steps/dp3concat.cwl
@@ -1,6 +1,6 @@
 class: CommandLineTool
 cwlVersion: v1.2
-id: dpppconcat
+id: dp3concat
 baseCommand:
   - DP3
 inputs:
diff --git a/steps/sort_times_into_freqGroups.cwl b/steps/sort_times_into_freqGroups.cwl
index 94f4a21a3755985a0c48d860b2630adb3fb56df3..a9b2eb530835e9a3e2bcfda08b580e61c787d675 100644
--- a/steps/sort_times_into_freqGroups.cwl
+++ b/steps/sort_times_into_freqGroups.cwl
@@ -14,10 +14,10 @@ inputs:
       type: int?
       default: 10
       doc: Number of how many files should be grouped together in frequency.
-    - id: NDPPPfill
+    - id: DP3fill
       type: boolean?
       default: True
-      doc: Add dummy file-names for missing frequencies, so that NDPPP can fill the data with flagged dummy data.
+      doc: Add dummy file-names for missing frequencies, so that DP3 can fill the data with flagged dummy data.
     - id: stepname
       type: string?
       default: '.ms'
@@ -29,11 +29,11 @@ inputs:
     - id: mergeLastGroup
       type: boolean?
       default: False
-      doc: Add dummy file-names for missing frequencies, so that NDPPP can fill the data with flagged dummy data.
+      doc: Add dummy file-names for missing frequencies, so that DP3 can fill the data with flagged dummy data.
     - id: truncateLastSBs
       type: boolean?
       default: True
-      doc: Add dummy file-names for missing frequencies, so that NDPPP can fill the data with flagged dummy data.
+      doc: Add dummy file-names for missing frequencies, so that DP3 can fill the data with flagged dummy data.
 requirements:
   - class: InlineJavascriptRequirement
   - class: InitialWorkDirRequirement
@@ -49,12 +49,12 @@ requirements:
 
           numbands = inputs['numbands']
           stepname = inputs['stepname']
-          NDPPPfill = inputs['NDPPPfill']
+          DP3fill = inputs['DP3fill']
           mergeLastGroup = inputs['mergeLastGroup']
           truncateLastSBs = inputs['truncateLastSBs']
           firstSB = inputs['firstSB']
 
-          output = sort_times_into_freqGroups(mss, numbands, NDPPPfill, stepname, mergeLastGroup, truncateLastSBs, firstSB)
+          output = sort_times_into_freqGroups(mss, numbands, DP3fill, stepname, mergeLastGroup, truncateLastSBs, firstSB)
 
           filenames  = output['filenames']
           groupnames = output['groupnames']
diff --git a/workflows/HBA_calibrator.cwl b/workflows/HBA_calibrator.cwl
index fe9c79980f30d9ee62106a684ec4d8a38f9f1d91..6ac44938f53f8d104d22726e43cb2e665be1be0f 100644
--- a/workflows/HBA_calibrator.cwl
+++ b/workflows/HBA_calibrator.cwl
@@ -86,7 +86,7 @@ inputs:
   - id: tables2export
     type: string?
     default: clock
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -197,8 +197,8 @@ steps:
         source: clock_smooth
       - id: tables2export
         source: tables2export
-      - id: max_dppp_threads
-        source: max_dppp_threads
+      - id: max_dp3_threads
+        source: max_dp3_threads
       - id: memoryperc
         source: memoryperc
       - id: min_separation
diff --git a/workflows/HBA_target.cwl b/workflows/HBA_target.cwl
index ba9d64d7a6540992ef556b64ec020a84a6fbd4c5..3c439b169d1b044f52ce4983a0bec5379cd9eb09 100644
--- a/workflows/HBA_target.cwl
+++ b/workflows/HBA_target.cwl
@@ -74,7 +74,7 @@ inputs:
   - id: updateweights
     type: boolean?
     default: true
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -221,8 +221,8 @@ steps:
         source: demix
       - id: updateweights
         source: updateweights
-      - id: max_dppp_threads
-        source: max_dppp_threads
+      - id: max_dp3_threads
+        source: max_dp3_threads
       - id: memoryperc
         source: memoryperc
       - id: min_separation
diff --git a/workflows/LBA_calibrator.cwl b/workflows/LBA_calibrator.cwl
index 1341938ffadbfdfb378f7cfbc4075d95de04561c..ba0bfd5fec9b01bdc33881c584dc65dfd062e996 100644
--- a/workflows/LBA_calibrator.cwl
+++ b/workflows/LBA_calibrator.cwl
@@ -86,7 +86,7 @@ inputs:
   - id: tables2export
     type: string?
     default: phaseOrig
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -195,8 +195,8 @@ steps:
         source: clock_smooth
       - id: tables2export
         source: tables2export
-      - id: max_dppp_threads
-        source: max_dppp_threads
+      - id: max_dp3_threads
+        source: max_dp3_threads
       - id: memoryperc
         source: memoryperc
       - id: min_separation
diff --git a/workflows/linc_calibrator.cwl b/workflows/linc_calibrator.cwl
index f6ec7a22c2aee8bd09e8ee8b4edf0be066eb9531..6ca990f207c59e88040bc853b1f45af5d923fd04 100644
--- a/workflows/linc_calibrator.cwl
+++ b/workflows/linc_calibrator.cwl
@@ -85,7 +85,7 @@ inputs:
   - id: tables2export
     type: string?
     default: clock
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -178,8 +178,8 @@ steps:
         source: flagunconverged
       - id: demix
         source: demix
-      - id: max_dppp_threads
-        source: max_dppp_threads
+      - id: max_dp3_threads
+        source: max_dp3_threads
       - id: memoryperc
         source: memoryperc
       - id: flag_baselines
diff --git a/workflows/linc_calibrator/ndppp_prep_cal.cwl b/workflows/linc_calibrator/dp3_prep_cal.cwl
similarity index 93%
rename from workflows/linc_calibrator/ndppp_prep_cal.cwl
rename to workflows/linc_calibrator/dp3_prep_cal.cwl
index 88992a6b0ee24f0553f7ddb8e801027a662b908f..4d95fec0d4354ab9677294a68c99a1265089237a 100644
--- a/workflows/linc_calibrator/ndppp_prep_cal.cwl
+++ b/workflows/linc_calibrator/dp3_prep_cal.cwl
@@ -1,7 +1,7 @@
 class: Workflow
 cwlVersion: v1.2
-id: ndppp_prep_cal
-label: ndppp_prep_cal
+id: dp3_prep_cal
+label: dp3_prep_cal
 inputs:
   - id: baselines_to_flag
     type: string[]?
@@ -67,7 +67,7 @@ outputs:
     type: Directory
   - id: logfile
     outputSource:
-      - concat_logfiles_dppp/output
+      - concat_logfiles_dp3/output
     type: File
   - id: flagged_fraction_dict
     outputSource:
@@ -114,7 +114,7 @@ steps:
         source: lbfgs_robustdof
     out:
       - id: output
-    run: ../../steps/dppp_make_parset_cal.cwl
+    run: ../../steps/dp3_make_parset_cal.cwl
     label: make_parset
   - id: dp3_execute
     in:
@@ -143,19 +143,19 @@ steps:
       - id: msout
       - id: flagged_fraction_dict
       - id: logfile
-    run: ../../steps/dppp_prep_cal.cwl
+    run: ../../steps/dp3_prep_cal.cwl
     label: DP3.Execute
-  - id: concat_logfiles_dppp
+  - id: concat_logfiles_dp3
     in:
       - id: file_list
         source:
           - dp3_execute/logfile
       - id: file_prefix
-        default: dppp
+        default: dp3
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
-    label: concat_logfiles_dppp
+    label: concat_logfiles_dp3
 requirements:
   - class: SubworkflowFeatureRequirement
   - class: StepInputExpressionRequirement
diff --git a/workflows/linc_calibrator/prep.cwl b/workflows/linc_calibrator/prep.cwl
index a709288e795edb6cc6a923a11a625009ae351552..0e1fbb0942d0370e6b81d42d65c62af00351807c 100644
--- a/workflows/linc_calibrator/prep.cwl
+++ b/workflows/linc_calibrator/prep.cwl
@@ -19,7 +19,7 @@ inputs:
     default: false
   - id: demix
     type: boolean?
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -111,7 +111,7 @@ outputs:
     type: string[]
   - id: flagged_fraction_dict
     outputSource:
-      - ndppp_prep_cal/flagged_fraction_dict
+      - dp3_prep_cal/flagged_fraction_dict
     type: string[]
   - id: logfiles
     outputSource:
@@ -136,7 +136,7 @@ steps:
       - id: output
     run: ../../steps/selectfirstdirectory.cwl
     label: select_only_first
-  - id: ndppp_prep_cal
+  - id: dp3_prep_cal
     in:
       - id: baselines_to_flag
         default: []
@@ -180,7 +180,7 @@ steps:
         source: find_skymodel_cal/model_name
       - id: ntimechunk
         default: 10
-        source: max_dppp_threads
+        source: max_dp3_threads
       - id: subtract_sources
         source: check_demix/out_demix_sources
       - id: lbfgs_historysize
@@ -191,8 +191,8 @@ steps:
       - id: msout
       - id: flagged_fraction_dict
       - id: logfile
-    run: ./ndppp_prep_cal.cwl
-    label: ndppp_prep_cal
+    run: ./dp3_prep_cal.cwl
+    label: dp3_prep_cal
     scatter:
       - msin
   - id: predict_calibrate
@@ -224,7 +224,7 @@ steps:
     in:
       - id: msin
         linkMerge: merge_flattened
-        source: ndppp_prep_cal/msout
+        source: dp3_prep_cal/msout
       - id: verbose
         default: true
       - id: concatenate-frequency
@@ -300,9 +300,9 @@ steps:
       - id: file_list
         linkMerge: merge_flattened
         source:
-          - ndppp_prep_cal/logfile
+          - dp3_prep_cal/logfile
       - id: file_prefix
-        default: ndppp_prep_cal
+        default: dp3_prep_cal
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
diff --git a/workflows/linc_target.cwl b/workflows/linc_target.cwl
index c1f5d5b8b7bbc5afb90a5626f39acae21f51b733..46cef17ba633ee645282614a69c46de0f52e9491 100644
--- a/workflows/linc_target.cwl
+++ b/workflows/linc_target.cwl
@@ -74,7 +74,7 @@ inputs:
   - id: updateweights
     type: boolean?
     default: true
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -229,8 +229,8 @@ steps:
         source: apply_beam
       - id: updateweights
         source: updateweights
-      - id: max_dppp_threads
-        source: max_dppp_threads
+      - id: max_dp3_threads
+        source: max_dp3_threads
       - id: memoryperc
         source: memoryperc
       - id: min_separation
diff --git a/workflows/linc_target/concat.cwl b/workflows/linc_target/concat.cwl
index bbae3ea8a0f4ec1827782c0a06d4791f2b630050..1ae800b7ae1c1f6def03b0f92d58654748bc3ea2 100644
--- a/workflows/linc_target/concat.cwl
+++ b/workflows/linc_target/concat.cwl
@@ -21,15 +21,15 @@ inputs:
 outputs:
   - id: flagged_fraction_dict
     outputSource:
-      - dpppconcat/flagged_fraction_dict
+      - dp3concat/flagged_fraction_dict
     type: string
   - id: msout
     outputSource:
-      - dpppconcat/msout
+      - dp3concat/msout
     type: Directory
-  - id: dpppconcat.log
+  - id: dp3concat.log
     outputSource:
-      - concat_logfiles_dpppconcat/output
+      - concat_logfiles_dp3concat/output
     type: File
 steps:
   - id: filter_ms_group
@@ -46,7 +46,7 @@ steps:
       - id: selected_ms
     run: ../../steps/filter_ms_group.cwl
     label: filter_ms_group
-  - id: dpppconcat
+  - id: dp3concat
     in:
       - id: msin
         source:
@@ -81,18 +81,18 @@ steps:
       - id: msout
       - id: flagged_fraction_dict
       - id: logfile
-    run: ../../steps/dpppconcat.cwl
-    label: dpppconcat
-  - id: concat_logfiles_dpppconcat
+    run: ../../steps/dp3concat.cwl
+    label: dp3concat
+  - id: concat_logfiles_dp3concat
     in:
       - id: file_list
         source:
-          - dpppconcat/logfile
+          - dp3concat/logfile
       - id: file_prefix
-        default: dpppconcat
+        default: dp3concat
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
-    label: concat_logfiles_dpppconcat
+    label: concat_logfiles_dp3concat
 
 requirements: []
diff --git a/workflows/linc_target/ndppp_prep_targ.cwl b/workflows/linc_target/dp3_prep_targ.cwl
similarity index 96%
rename from workflows/linc_target/ndppp_prep_targ.cwl
rename to workflows/linc_target/dp3_prep_targ.cwl
index 46168a249cbe76807fe7746d2b05ecf689c959b3..f56a63edde2ec9a174c76c93ae09c81251832804 100644
--- a/workflows/linc_target/ndppp_prep_targ.cwl
+++ b/workflows/linc_target/dp3_prep_targ.cwl
@@ -1,7 +1,7 @@
 class: Workflow
 cwlVersion: v1.2
-id: ndppp_prep_targ
-label: ndppp_prep_targ
+id: dp3_prep_targ
+label: dp3_prep_targ
 inputs:
   - id: baselines_to_flag
     type: string[]?
@@ -101,7 +101,7 @@ outputs:
     type: string
   - id: prep_logfile
     outputSource:
-      - concat_logfiles_dppp/output
+      - concat_logfiles_dp3/output
     type: File
   - id: predict_logfile
     outputSource:
@@ -177,19 +177,19 @@ steps:
         source: lbfgs_robustdof
     out:
       - id: output
-    run: ../../steps/dppp_make_parset_target.cwl
+    run: ../../steps/dp3_make_parset_target.cwl
     label: make_parset
-  - id: concat_logfiles_dppp
+  - id: concat_logfiles_dp3
     in:
       - id: file_list
         source:
           - dp3_execute/logfile
       - id: file_prefix
-        default: dppp
+        default: dp3
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
-    label: concat_logfiles_dppp
+    label: concat_logfiles_dp3
   - id: concat_logfiles_predict
     in:
       - id: file_list
@@ -250,7 +250,7 @@ steps:
       - id: flagged_fraction_dict_initial
       - id: flagged_fraction_dict_prep
       - id: logfile
-    run: ../../steps/dppp_prep_target.cwl
+    run: ../../steps/dp3_prep_target.cwl
     label: DP3.Execute
   - id: predict
     in:
diff --git a/workflows/linc_target/gsmcal.cwl b/workflows/linc_target/gsmcal.cwl
index f3b6b3474dcf3af54fdbaddb82f3cc35632ee901..5c66cd5f3871de87ded976778097cb341b3db968 100644
--- a/workflows/linc_target/gsmcal.cwl
+++ b/workflows/linc_target/gsmcal.cwl
@@ -83,7 +83,7 @@ outputs:
       - concat_logfiles_RefAnt/output
       - sort_times_into_freqGroups/logfile
       - concat_logfiles_calib/output
-      - concat_logfiles_dpppconcat/output
+      - concat_logfiles_dp3concat/output
       - concat_logfiles_blsmooth/output
       - concat_logfiles_unflagged/output
       - aoflag/logfile
@@ -153,10 +153,10 @@ steps:
           - msin
       - id: numbands
         source: num_SBs_per_group
-      - id: NDPPPfill
+      - id: DP3fill
         default: true
       - id: stepname
-        default: .dpppconcat
+        default: .dp3concat
       - id: firstSB
         source: reference_stationSB
       - id: truncateLastSBs
@@ -168,17 +168,17 @@ steps:
       - id: logfile
     run: ../../steps/sort_times_into_freqGroups.cwl
     label: sorttimesintofreqGroups
-  - id: concat_logfiles_dpppconcat
+  - id: concat_logfiles_dp3concat
     in:
       - id: file_list
         source:
-          - concat/dpppconcat.log
+          - concat/dp3concat.log
       - id: file_prefix
-        default: dpppconcat
+        default: dp3concat
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
-    label: concat_logfiles_dpppconcat
+    label: concat_logfiles_dp3concat
   - id: concat_logfiles_blsmooth
     in:
       - id: file_list
@@ -273,7 +273,7 @@ steps:
     out:
       - id: msout
       - id: flagged_fraction_dict
-      - id: dpppconcat.log
+      - id: dp3concat.log
     run: ./concat.cwl
     label: concat
     scatter:
diff --git a/workflows/linc_target/prep.cwl b/workflows/linc_target/prep.cwl
index 19de109e6491e8dd9219d17cf5fb5b3071dbc1d9..6d7c9da0122c1dd78b2072d1bc71420b0b8e32e5 100644
--- a/workflows/linc_target/prep.cwl
+++ b/workflows/linc_target/prep.cwl
@@ -62,7 +62,7 @@ inputs:
   - id: updateweights
     type: boolean?
     default: true
-  - id: max_dppp_threads
+  - id: max_dp3_threads
     type: int?
     default: 10
   - id: memoryperc
@@ -142,7 +142,7 @@ outputs:
     pickValue: all_non_null
   - id: msout
     outputSource:
-      - dppp_prep_target/msout
+      - dp3_prep_target/msout
     type: Directory[]
   - id: check_Ateam_separation.json
     outputSource:
@@ -212,7 +212,7 @@ steps:
     in:
       - id: flagged_fraction_dict
         source:
-          - dppp_prep_target/initial_flags_out
+          - dp3_prep_target/initial_flags_out
       - id: filter_station
         default: ''
       - id: state
@@ -226,7 +226,7 @@ steps:
     in:
       - id: flagged_fraction_dict
         source:
-          - dppp_prep_target/prep_flags_out
+          - dp3_prep_target/prep_flags_out
       - id: filter_station
         default: ''
       - id: state
@@ -331,7 +331,7 @@ steps:
       - id: parset
     run: ../../steps/LoSoTo.Plot.cwl
     label: losoto_plot_RM
-  - id: dppp_prep_target
+  - id: dp3_prep_target
     in:
       - id: baselines_to_flag
         source:
@@ -363,7 +363,7 @@ steps:
       - id: process_baselines_target
         source: process_baselines_target
       - id: ntimechunk
-        source: max_dppp_threads
+        source: max_dp3_threads
       - id: subtract_sources
         source: check_demix/out_demix_sources
       - id: parmdb
@@ -400,8 +400,8 @@ steps:
       - id: clipper_logfile
       - id: msout
       - id: clipper_output
-    run: ./ndppp_prep_targ.cwl
-    label: ndppp_prep_target
+    run: ./dp3_prep_targ.cwl
+    label: dp3_prep_target
     scatter:
       - msin
   - id: plot_Ateamclipper
@@ -420,7 +420,7 @@ steps:
       - id: file_list
         linkMerge: merge_flattened
         source:
-          - dppp_prep_target/clipper_output
+          - dp3_prep_target/clipper_output
       - id: file_prefix
         default: Ateamclipper
       - id: file_suffix
@@ -437,9 +437,9 @@ steps:
       - id: file_list
         linkMerge: merge_flattened
         source:
-          - dppp_prep_target/prep_logfile
+          - dp3_prep_target/prep_logfile
       - id: file_prefix
-        default: ndppp_prep_targ
+        default: dp3_prep_targ
     out:
       - id: output
     run: ../../steps/concatenate_files.cwl
@@ -449,7 +449,7 @@ steps:
       - id: file_list
         linkMerge: merge_flattened
         source:
-          - dppp_prep_target/predict_logfile
+          - dp3_prep_target/predict_logfile
       - id: file_prefix
         default: predict_targ
       - id: execute
@@ -464,7 +464,7 @@ steps:
       - id: file_list
         linkMerge: merge_flattened
         source:
-          - dppp_prep_target/clipper_logfile
+          - dp3_prep_target/clipper_logfile
         pickValue: all_non_null
       - id: file_prefix
         default: Ateamclipper
diff --git a/scripts/sort_times_into_freqGroups.py b/scripts/sort_times_into_freqGroups.py
index 4c401ff53cda51f6eb542bf22c9249aa4d971b51..829792b4342d7ab18f09dd1835603392487fde37 100755
--- a/scripts/sort_times_into_freqGroups.py
+++ b/scripts/sort_times_into_freqGroups.py
@@ -59,7 +59,7 @@ def input2int(invar):
 
 
 ########################################################################
-def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False, truncateLastSBs=True, firstSB=None):
+def main(MSfile, numSB=10, DP3fill=True, stepname=None, mergeLastGroup=False, truncateLastSBs=True, firstSB=None):
     """
     Check a list of MS files for missing frequencies
 
@@ -71,13 +71,13 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
         How many files should go into one frequency group. Values <= 0 mean put 
         all files of the same time-step into one group.
         default = -1
-    NDPPPfill : bool, optional
-        Add dummy file-names for missing frequencies, so that NDPPP can
+    DP3fill : bool, optional
+        Add dummy file-names for missing frequencies, so that DP3 can
         fill the data with flagged dummy data.
         default = True
     target_path : str, optional
         Change the path of the "groups" files to this. (I.e. write output files 
         into this directory with the subsequent NDPPP call.)
         default = keep path of input files
     stepname : str, optional
         Add this step-name into the file-names of the output files.
@@ -90,7 +90,7 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
         mergeLastGroup = False, truncateLastSBs = True:
           ignore last files, that don't make for a full group (not all files are used).
         mergeLastGroup = False, truncateLastSBs = False:
-          keep inclomplete last group, or - with NDPPPfill=True - fill
+          keep inclomplete last group, or - with DP3fill=True - fill
           last group with dummies.      
     firstSB : int, optional
         If set, then reference the grouping of files to this station-subband. As if a file 
@@ -104,7 +104,7 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
 
     """
 
-    NDPPPfill = input2bool(NDPPPfill)
+    DP3fill = input2bool(DP3fill)
     mergeLastGroup = input2bool(mergeLastGroup)
     truncateLastSBs = input2bool(truncateLastSBs)
     firstSB = input2int(firstSB)
@@ -197,15 +197,15 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
     # this is the case for concatenating all subbands
        groupBW = maxfreq-minfreq
     truncateLastSBs = input2bool(False)
-    NDPPPfill = input2bool(True)
+    DP3fill = input2bool(True)
     freqborders = np.arange(minfreq,maxfreq,groupBW)
     if mergeLastGroup:
         freqborders[-1] = maxfreq
     elif truncateLastSBs:
         pass #nothing to do! # left to make the logic more clear!
-    elif not truncateLastSBs and NDPPPfill:
+    elif not truncateLastSBs and DP3fill:
         freqborders = np.append(freqborders,(freqborders[-1]+groupBW))
-    elif not truncateLastSBs and not NDPPPfill:
+    elif not truncateLastSBs and not DP3fill:
         freqborders = np.append(freqborders,maxfreq)
 
     freqborders = freqborders[freqborders>(np.min(freqliste)-groupBW)]
@@ -233,7 +233,7 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
                     else:
                         (freq,fname) = (1e12,'This_shouldn\'t_show_up')
                     skip_this = False
-                elif NDPPPfill:
+                elif DP3fill:
                     files.append('dummy.ms')
             if not skip_this:
                 freqID = int((freqborders[groupIdx]+freqborders[groupIdx+1])/2e6)
@@ -265,8 +265,8 @@ if __name__ == '__main__':
                         help='One (or more MSs) for which you want to get the antenna list.')
     parser.add_argument('--numbands', type=int, default=10,
                         help='Number of how many files should be grouped together in frequency. (default=10)')
-    parser.add_argument('--NDPPPfill', type=bool, default=True,
-                        help='Add dummy file-names for missing frequencies, so that NDPPP can fill the data with flagged dummy data.')
+    parser.add_argument('--DP3fill', type=bool, default=True,
+                        help='Add dummy file-names for missing frequencies, so that DP3 can fill the data with flagged dummy data.')
     parser.add_argument('--stepname', type=str, default=None,
                         help='Add this step-name into the file-names of the output files.')
     parser.add_argument('--mergeLastGroup', type=bool, default=False,
@@ -289,4 +289,4 @@ if __name__ == '__main__':
     logging.root.addHandler(log)
 
     # first argument: pattern for measurement-sets
-    main(args.MSfiles, numSB=args.numbands, NDPPPfill=args.NDPPPfill, stepname=args.stepname, mergeLastGroup=args.mergeLastGroup, truncateLastSBs=args.truncateLastSBs, firstSB=args.firstSB)
+    main(args.MSfiles, numSB=args.numbands, DP3fill=args.DP3fill, stepname=args.stepname, mergeLastGroup=args.mergeLastGroup, truncateLastSBs=args.truncateLastSBs, firstSB=args.firstSB)
@@ -71,13 +71,13 @@ def main(MSfile, numSB=10, NDPPPfill=True, stepname=None, mergeLastGroup=False,
     target_path : str, optional
         Change the path of the "groups" files to this. (I.e. write output files 
-        into this directory with the subsequent NDPPP call.)
+        into this directory with the subsequent DP3 call.)
         default = keep path of input files
     stepname : str, optional